[Mesa-dev] [PATCH 3/3] vbo: improve comments on vbo_draw_func()

Brian Paul brianp at vmware.com
Wed Feb 7 05:44:06 UTC 2018


And rename a parameter name.
---
 src/mesa/vbo/vbo.h | 9 +++++----
 1 file changed, 5 insertions(+), 4 deletions(-)

diff --git a/src/mesa/vbo/vbo.h b/src/mesa/vbo/vbo.h
index a04f9b8..d594ba8 100644
--- a/src/mesa/vbo/vbo.h
+++ b/src/mesa/vbo/vbo.h
@@ -149,9 +149,10 @@ vbo_save_EndCallList(struct gl_context *ctx);
  * \param index_bounds_valid  are min_index and max_index valid?
  * \param min_index  lowest vertex index used
  * \param max_index  highest vertex index used
  * \param tfb_vertcount  describes TFB output, or NULL
  * \param stream  If called via DrawTransformFeedback, specifies the vertex
  *                stream buffer from which to get the vertex count
  * \param indirect  If any prims are indirect, this specifies the buffer
  *                  to find the "DrawArrays/ElementsIndirectCommand" data.
  *                  This may be deprecated in the future
@@ -164,7 +165,7 @@ typedef void (*vbo_draw_func)(struct gl_context *ctx,
                               GLuint min_index,
                               GLuint max_index,
                               struct gl_transform_feedback_object *tfb_vertcount,
-                              unsigned stream,
+                              unsigned tfb_stream,
                               struct gl_buffer_object *indirect);
 
 
@@ -149,9 +149,10 @@ vbo_save_EndCallList(struct gl_context *ctx);
  * \param min_index  lowest vertex index used
  * \param max_index  highest vertex index used
- * \param tfb_vertcount  describes TFB output, or NULL
- * \param stream  If called via DrawTransformFeedback, specifies the vertex
- *                stream buffer from which to get the vertex count
+ * \param tfb_vertcount  if non-null, indicates which transform feedback
+ *                       object has the vertex count.
+ * \param tfb_stream  If called via DrawTransformFeedbackStream, specifies the
+ *                    vertex stream buffer from which to get the vertex count.
  * \param indirect  If any prims are indirect, this specifies the buffer
  *                  to find the "DrawArrays/ElementsIndirectCommand" data.
-- 
2.7.4



More information about the mesa-dev mailing list